==> igniteui-react-charts-16.4.1.tgz: package/ES2015/StepLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { IIsCategoryBased_$type } from "./IIsCategoryBased";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { typeCast, Array_$type, runOn, markType } from "igniteui-react-core/ES2015/type";
import { ISortingAxis_$type } from "./ISortingAxis";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { Path } from "igniteui-react-core/ES2015/Path";
import { ScalerParams } from "./ScalerParams";
import { intDivide, isNaN_ } from "igniteui-react-core/ES2015/number";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Color } from "igniteui-react-core/ES2015/Color";
export class StepLineSeries extends HorizontalAnchoredCategorySeries {
    constructor() {
        super();
        this.p7 = null;
        this.p7 = new CategoryLineRasterizer();
        this.ab = StepLineSeries.$;
    }
    bf() {
        return new StepLineSeriesView(this);
    }
    getHostReferenceValue() {
        return this.ed();
    }
    il(a) {
        super.il(a);
        this.p8 = a;
    }
    ac() {
        super.ac();
    }
    preferredCategoryMode(a) {
        return typeCast(ISortingAxis_$type, a) !== null ? 0 : 1;
    }
    get_ck() {
        return true;
    }
    get ck() {
        return this.get_ck();
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        c.c5();
    }
    bd() {
        if (this.be == 0) {
            return 2;
        }
        else {
            return super.bd();
        }
    }
    eb(a, b, c, d, e, f, g, h) {
        let i = NaN;
        if (c >= 0 && c < b.count) {
            i = b.item(c);
        }
        let j = NaN;
        if (d >= 0 && d < b.count) {
            j = b.item(d);
        }
        if (f == 0) {
            return j;
        }
        if (e == b.count - 1) {
            return i;
        }
        if (isNaN_(j) && g != 0 && a <= 0.5 && !h) {
            return i;
        }
        if (isNaN_(i) && g != 0 && a >= 0.5 && !h) {
            return j;
        }
        if (a > 0.5) {
            return j;
        }
        return i;
    }
    p9(a, b, c, d, e, f) {
        let g;
        if (b) {
            if (f) {
                g = (a & 1) == 0;
                if (g || (intDivide(a, 2)) + 1 < 0) {
                    return c.f._inner[(intDivide(a, 2))][0];
                }
                if (c.f.count == (intDivide(a, 2)) + 1) {
                    return c.f._inner[(intDivide(a, 2))][0];
                }
                return c.f._inner[(intDivide(a, 2)) + 1][0];
            }
            g = (a & 1) == 0;
            return c.f._inner[(intDivide(a, 2))][0] + (g ? d : -d);
        }
        if (f) {
            g = (a & 1) == 0;
            if (g || ((intDivide(a, 2)) + 1) >= c.f.count) {
                return c.f._inner[(intDivide(a, 2))][0];
            }
            if (c.f.count == (intDivide(a, 2)) + 1) {
                return c.f._inner[(intDivide(a, 2))][0];
            }
            return c.f._inner[(intDivide(a, 2)) + 1][0];
        }
        g = (a & 1) == 0;
        return c.f._inner[(intDivide(a, 2))][0] + (g ? -d : d);
    }
    oe(a, b) {
        super.oe(a, b);
        let c = b.bq;
        let d = b.bp;
        let e = this.getEffectiveViewport1(b);
        let f = typeCast(ISortingAxis_$type, this.po) != null;
        let g = this.po.b8;
        let h = 0;
        if (this.po != null) {
            h = 0.5 * this.po.getCategorySize(c, d, e);
        }
        let i = a.f;
        let j = 2 * i.count;
        let k = new List$1(Array_$type, 2, j);
        if (!this.po.b8) {
            for (let l = 0; l < j; l++) {
                let m = new Array(4);
                m[0] = this.p9(l, false, a, h, g, f);
                m[1] = a.f._inner[(intDivide(l, 2))][1];
                m[2] = this.p9(l, true, a, h, g, f);
                m[3] = a.f._inner[(intDivide(l, 2))][2];
                k.add(m);
            }
        }
        else {
            for (let n = 0; n < j; n++) {
                let o = new Array(4);
                o[0] = this.p9(n, true, a, h, g, f);
                o[1] = a.f._inner[(intDivide(n, 2))][1];
                o[2] = this.p9(n, true, a, h, g, f);
                o[3] = a.f._inner[(intDivide(n, 2))][2];
                k.add(o);
            }
        }
        let p = typeCast(StepLineSeriesView.$, b);
        let q = p.cl.d;
        this.m5.x(this, this.nq(), this.po, runOn(this, this.mr), this.ny(b), this.nz(b));
        let r = false;
        let s = this.m5.c;
        if (s != null) {
            r = true;
        }
        if (r) {
            let t = new ScalerParams(0, b.bq, b.bp, this.po.b8, e);
            this.oa(i, -1, this.valueColumn.count, this.po, t, b.n);
        }
        let u = p.db;
        let v = p.dc;
        let w = p.da;
        this.m5.ae(u, true, false, true, false);
        this.m5.ae(v, true, false, true, false);
        this.m5.ae(w, false, true, false, false);
        w._opacity = 0.75 * this.m5.i;
        if (b.cp(a)) {
            p.c6(j, k, false, 1, this.om(k, j - 1, b.bp, b.bq), q, this.eq);
            b.cs(a);
        }
    }
    get currentCategoryMode() {
        return this.preferredCategoryMode(this.po);
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
StepLineSeries.$t = markType(StepLineSeries, 'StepLineSeries', HorizontalAnchoredCategorySeries.$, [IIsCategoryBased_$type]);
export class StepLineSeriesView extends AnchoredCategorySeriesView {
    constructor(a) {
        super(a);
        this.c4 = null;
        this.de = new Path();
        this.dd = new Path();
        this.df = new Path();
        this.c9 = new Path();
        this.c8 = new Path();
        this.c7 = new Path();
        this.c4 = a;
    }
    get db() {
        return this.de;
    }
    get dc() {
        return this.df;
    }
    get da() {
        return this.dd;
    }
    c5() {
        this.dd.aj = null;
        this.de.aj = null;
        this.df.aj = null;
        this.an();
    }
    c6(a, b, c, d, e, f, g) {
        this.c4.p7.a = typeCast(ISortingAxis_$type, this.cn.fetchXAxis()) !== null ? true : false;
        this.c4.p7.m(this.de, this.dd, this.df, a, b, c, d, e, f, g);
        this.an();
    }
    a9() {
        super.a9();
        this.c8.aj = this.de.aj;
        this.c9.aj = this.df.aj;
        this.c7.aj = this.dd.aj;
        let a = this.bk();
        this.c8._stroke = a;
        this.c8.ac = this.e.eu + 3;
        this.c9._stroke = a;
        this.c9.ac = this.e.eu + 3;
        this.c7._fill = a;
        this.c7._opacity = 1;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            if (b) {
                a.s(this.c7);
                a.s(this.c8);
                a.s(this.c9);
            }
            else {
                a.s(this.dd);
                a.s(this.de);
                a.s(this.df);
            }
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.de, "lowerShape", ["Lower", "Main"]);
        this.e.a2.exportPathData(a, this.df, "upperShape", ["Upper"]);
        this.e.a2.exportPathData(a, this.dd, "translucentShape", ["Translucent"]);
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 3;
        this.e.es = 1;
        this.e.et = 4;
        this.e.ds = false;
    }
}
StepLineSeriesView.$t = markType(StepLineSeriesView, 'StepLineSeriesView', AnchoredCategorySeriesView.$);

==> igniteui-react-charts-16.6.4.tgz: package/ES2015/StepLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { IIsCategoryBased_$type } from "./IIsCategoryBased";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { typeCast, Array_$type, runOn, markType } from "igniteui-react-core/ES2015/type";
import { ISortingAxis_$type } from "./ISortingAxis";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { Path } from "igniteui-react-core/ES2015/Path";
import { ScalerParams } from "./ScalerParams";
import { intDivide, isNaN_ } from "igniteui-react-core/ES2015/number";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Color } from "igniteui-react-core/ES2015/Color";
export class StepLineSeries extends HorizontalAnchoredCategorySeries {
    constructor() {
        super();
        this.p8 = null;
        this.p8 = new CategoryLineRasterizer();
        this.ab = StepLineSeries.$;
    }
    bf() {
        return new StepLineSeriesView(this);
    }
    getHostReferenceValue() {
        return this.ed();
    }
    il(a) {
        super.il(a);
        this.p9 = a;
    }
    ac() {
        super.ac();
    }
    preferredCategoryMode(a) {
        return typeCast(ISortingAxis_$type, a) !== null ? 0 : 1;
    }
    get_ck() {
        return true;
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        c.c7();
    }
    bd() {
        if (this.be == 0) {
            return 2;
        }
        else {
            return super.bd();
        }
    }
    eb(a, b, c, d, e, f, g, h) {
        let i = NaN;
        if (c >= 0 && c < b.count) {
            i = b.item(c);
        }
        let j = NaN;
        if (d >= 0 && d < b.count) {
            j = b.item(d);
        }
        if (f == 0) {
            return j;
        }
        if (e == b.count - 1) {
            return i;
        }
        if (isNaN_(j) && g != 0 && a <= 0.5 && !h) {
            return i;
        }
        if (isNaN_(i) && g != 0 && a >= 0.5 && !h) {
            return j;
        }
        if (a > 0.5) {
            return j;
        }
        return i;
    }
    qa(a, b, c, d, e, f) {
        let g;
        if (b) {
            if (f) {
                g = (a & 1) == 0;
                if (g || (intDivide(a, 2)) + 1 < 0) {
                    return c.f._inner[(intDivide(a, 2))][0];
                }
                if (c.f.count == (intDivide(a, 2)) + 1) {
                    return c.f._inner[(intDivide(a, 2))][0];
                }
                return c.f._inner[(intDivide(a, 2)) + 1][0];
            }
            g = (a & 1) == 0;
            return c.f._inner[(intDivide(a, 2))][0] + (g ? d : -d);
        }
        if (f) {
            g = (a & 1) == 0;
            if (g || ((intDivide(a, 2)) + 1) >= c.f.count) {
                return c.f._inner[(intDivide(a, 2))][0];
            }
            if (c.f.count == (intDivide(a, 2)) + 1) {
                return c.f._inner[(intDivide(a, 2))][0];
            }
            return c.f._inner[(intDivide(a, 2)) + 1][0];
        }
        g = (a & 1) == 0;
        return c.f._inner[(intDivide(a, 2))][0] + (g ? -d : d);
    }
    of(a, b) {
        super.of(a, b);
        let c = b.bs;
        let d = b.br;
        let e = this.getEffectiveViewport1(b);
        let f = typeCast(ISortingAxis_$type, this.pp) != null;
        let g = this.pp.b8;
        let h = 0;
        if (this.pp != null) {
            h = 0.5 * this.pp.getCategorySize(c, d, e);
        }
        let i = a.f;
        let j = 2 * i.count;
        let k = new List$1(Array_$type, 2, j);
        if (!this.pp.b8) {
            for (let l = 0; l < j; l++) {
                let m = new Array(4);
                m[0] = this.qa(l, false, a, h, g, f);
                m[1] = a.f._inner[(intDivide(l, 2))][1];
                m[2] = this.qa(l, true, a, h, g, f);
                m[3] = a.f._inner[(intDivide(l, 2))][2];
                k.add(m);
            }
        }
        else {
            for (let n = 0; n < j; n++) {
                let o = new Array(4);
                o[0] = this.qa(n, true, a, h, g, f);
                o[1] = a.f._inner[(intDivide(n, 2))][1];
                o[2] = this.qa(n, true, a, h, g, f);
                o[3] = a.f._inner[(intDivide(n, 2))][2];
                k.add(o);
            }
        }
        let p = typeCast(StepLineSeriesView.$, b);
        let q = p.cn.d;
        this.m5.x(this, this.nq(), this.pp, runOn(this, this.mr), this.ny(b), this.nz(b));
        let r = false;
        let s = this.m5.c;
        if (s != null) {
            r = true;
        }
        if (r) {
            let t = new ScalerParams(0, b.bs, b.br, this.pp.b8, e);
            this.ob(i, -1, this.valueColumn.count, this.pp, t, b.n);
        }
        let u = p.dd;
        let v = p.de;
        let w = p.dc;
        this.m5.ae(u, true, false, true, false);
        this.m5.ae(v, true, false, true, false);
        this.m5.ae(w, false, true, false, false);
        w._opacity = 0.75 * this.m5.i;
        if (b.cr(a)) {
            p.c8(j, k, false, 1, this.on(k, j - 1, b.br, b.bs), q, this.eq);
            b.cu(a);
        }
    }
    get currentCategoryMode() {
        return this.preferredCategoryMode(this.pp);
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
StepLineSeries.$t = markType(StepLineSeries, 'StepLineSeries', HorizontalAnchoredCategorySeries.$, [IIsCategoryBased_$type]);
export class StepLineSeriesView extends AnchoredCategorySeriesView {
    constructor(a) {
        super(a);
        this.c6 = null;
        this.dg = new Path();
        this.df = new Path();
        this.dh = new Path();
        this.db = new Path();
        this.da = new Path();
        this.c9 = new Path();
        this.c6 = a;
    }
    get dd() {
        return this.dg;
    }
    get de() {
        return this.dh;
    }
    get dc() {
        return this.df;
    }
    c7() {
        this.df.aj = null;
        this.dg.aj = null;
        this.dh.aj = null;
        this.an();
    }
    c8(a, b, c, d, e, f, g) {
        this.c6.p8.a = typeCast(ISortingAxis_$type, this.cp.fetchXAxis()) !== null ? true : false;
        this.c6.p8.m(this.dg, this.df, this.dh, a, b, c, d, e, f, g);
        this.an();
    }
    a9() {
        super.a9();
        this.da.aj = this.dg.aj;
        this.db.aj = this.dh.aj;
        this.c9.aj = this.df.aj;
        let a = this.bl();
        this.da._stroke = a;
        this.da.ac = this.e.eu + 3;
        this.db._stroke = a;
        this.db.ac = this.e.eu + 3;
        this.c9._fill = a;
        this.c9._opacity = 1;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            if (b) {
                a.s(this.c9);
                a.s(this.da);
                a.s(this.db);
            }
            else {
                a.s(this.df);
                a.s(this.dg);
                a.s(this.dh);
            }
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.dg, "lowerShape", ["Lower", "Main"]);
        this.e.a2.exportPathData(a, this.dh, "upperShape", ["Upper"]);
        this.e.a2.exportPathData(a, this.df, "translucentShape", ["Translucent"]);
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 3;
        this.e.es = 1;
        this.e.et = 4;
        this.e.ds = false;
    }
}
StepLineSeriesView.$t = markType(StepLineSeriesView, 'StepLineSeriesView', AnchoredCategorySeriesView.$);
